@@ -1,6 +1,5 @@
 use assert_matches::assert_matches;
-
-use prae;
+use prae::Guard;
 
 #[derive(Debug)]
 pub struct UsernameError;
@@ -8,11 +7,11 @@ pub struct UsernameError;
 prae::define! {
     pub Username: String
     adjust   |u| *u = u.trim().to_owned()
-    validate |u| -> Option<UsernameError> {
+    validate |u| -> Result<(), UsernameError> {
         if u.is_empty() {
-            Some(UsernameError)
+            Err(UsernameError)
         } else {
-            None
+            Ok(())
         }
     }
 }
